==> zio-aws-mediapackage_3-5.17.130.2-sources.jar: zio/aws/mediapackage/model/TagResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class TagResourceRequest(
    resourceArn: __string,
    tags: Map[__string, __string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.TagResourceRequest = {
    import TagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .tags(
        tags
          .map({ case (key, value) =>
            (__string.unwrap(key): java.lang.String) -> (__string
              .unwrap(value): java.lang.String)
          })
          .asJava
      )
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.TagResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.TagResourceRequest.wrap(buildAwsValue())
}
object TagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.TagResourceRequest =
      zio.aws.mediapackage.model.TagResourceRequest(resourceArn, tags)
    def resourceArn: __string
    def tags: Map[__string, __string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTags: ZIO[Any, Nothing, Map[__string, __string]] = ZIO.succeed(tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ) extends zio.aws.mediapackage.model.TagResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.resourceArn())
    override val tags: Map[__string, __string] = impl
      .tags()
      .asScala
      .map({ case (key, value) =>
        zio.aws.mediapackage.model.primitives.__string(
          key
        ) -> zio.aws.mediapackage.model.primitives.__string(value)
      })
      .toMap
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ): zio.aws.mediapackage.model.TagResourceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediapackage_3-5.17.146.1-sources.jar: zio/aws/mediapackage/model/TagResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class TagResourceRequest(
    resourceArn: __string,
    tags: Map[__string, __string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.TagResourceRequest = {
    import TagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .tags(
        tags
          .map({ case (key, value) =>
            (key: java.lang.String) -> (value: java.lang.String)
          })
          .asJava
      )
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.TagResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.TagResourceRequest.wrap(buildAwsValue())
}
object TagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.TagResourceRequest =
      zio.aws.mediapackage.model.TagResourceRequest(resourceArn, tags)
    def resourceArn: __string
    def tags: Map[__string, __string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTags: ZIO[Any, Nothing, Map[__string, __string]] = ZIO.succeed(tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ) extends zio.aws.mediapackage.model.TagResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
    override val tags: Map[__string, __string] = impl
      .tags()
      .asScala
      .map({ case (key, value) =>
        (key: __string) -> (value: __string)
      })
      .toMap
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.TagResourceRequest
  ): zio.aws.mediapackage.model.TagResourceRequest.ReadOnly = new Wrapper(impl)
}
